#ifndef EPIWORLD_COMMON_HPP
#define EPIWORLD_COMMON_HPP

#include "epiworld/epiworld.hpp"

#endif
